@@ -15,6 +15,7 @@
 from datetime import datetime
 import json
 import logging
+import multiprocessing
 import os
 import shutil
 import six
@@ -59,7 +60,7 @@ def write_default_ansible_cfg(work_dir,
         '/usr/share/ansible/tripleo-plugins/callback:'
         '/usr/share/ansible/plugins/callback:'
         '%s/callback_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
-    callbacks_whitelist = ','.join(['profile_tasks'])
+    callbacks_whitelist = ','.join(['tripleo', 'profile_tasks'])
     action_plugins_path = (
         '~/.ansible/plugins/action:'
         '/usr/share/ansible/plugins/action:'
@@ -89,6 +90,7 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'library', modules_path)
     config.set('defaults', 'callback_plugins', callbacks_path)
     config.set('defaults', 'callback_whitelist', callbacks_whitelist)
+    config.set('defaults', 'stdout_callback', 'tripleo')
     config.set('defaults', 'action_plugins', action_plugins_path)
     config.set('defaults', 'lookup_plugins', lookups_path)
     config.set('defaults', 'filter_plugins', filter_plugins_path)
@@ -100,7 +102,7 @@ def write_default_ansible_cfg(work_dir,
                     datetime.now().strftime("%Y-%m-%dT%H:%M:%S"))
         os.rename(log_path, new_path)
 
-    config.set('defaults', 'forks', '25')
+    config.set('defaults', 'forks', str(multiprocessing.cpu_count() * 10))
     config.set('defaults', 'timeout', '30')
     config.set('defaults', 'gather_timeout', '30')
 
@@ -108,7 +110,13 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'gathering', 'smart')
     config.set('defaults', 'fact_caching', 'jsonfile')
     config.set('defaults', 'fact_caching_connection',
-               '/var/lib/mistral/ansible_fact_cache')
+               '~/.ansible/fact_cache')
+
+    # Set the pull interval to lower CPU overhead
+    config.set('defaults', 'internal_poll_interval', '0.05')
+
+    # Set the interpreter discovery to auto mode.
+    config.set('defaults', 'interpreter_python', 'auto')
 
     # Expire facts in the fact cache after 7200s (2h)
     config.set('defaults', 'fact_caching_timeout', '7200')
@@ -120,7 +128,8 @@ def write_default_ansible_cfg(work_dir,
                '-o ControlMaster=auto '
                '-o ControlPersist=30m '
                '-o ServerAliveInterval=5 '
-               '-o ServerAliveCountMax=5')
+               '-o ServerAliveCountMax=5 '
+               '-o PreferredAuthentications=publickey')
     config.set('ssh_connection', 'control_path_dir',
                os.path.join(work_dir, 'ansible-ssh'))
     config.set('ssh_connection', 'retries', '8')
@@ -228,6 +237,7 @@ class AnsibleAction(actions.Action):
         # NOTE(flaper87): if it's a path, use it
         if (isinstance(self._ssh_private_key, six.string_types) and
                 os.path.exists(self._ssh_private_key)):
+            os.chmod(self._ssh_private_key, 0o600)
             return self._ssh_private_key
 
         path = os.path.join(self.work_dir, 'ssh_private_key')
@@ -458,6 +468,7 @@ class AnsiblePlaybookAction(base.TripleOAction):
         # NOTE(flaper87): if it's a path, use it
         if (isinstance(self._ssh_private_key, six.string_types) and
                 os.path.exists(self._ssh_private_key)):
+            os.chmod(self._ssh_private_key, 0o600)
             return self._ssh_private_key
 
         path = os.path.join(self.work_dir, 'ssh_private_key')
@@ -551,7 +562,7 @@ class AnsiblePlaybookAction(base.TripleOAction):
 
         if self.blacklisted_hostnames:
             host_pattern = ':'.join(
-                ['!%s' % h for h in self.blacklisted_hostnames])
+                ['!%s' % h for h in self.blacklisted_hostnames if h])
             command.extend(['--limit', host_pattern])
 
         if self.tags:
@@ -587,7 +598,8 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 env_variables.update({
                     # the whitelist could be collected from multiple
                     # arguments if we find a use case for it
-                    'ANSIBLE_CALLBACK_WHITELIST': 'profile_tasks',
+                    'ANSIBLE_CALLBACK_WHITELIST': 'tripleo,profile_tasks',
+                    'ANSIBLE_STDOUT_CALLBACK': 'tripleo',
                     'PROFILE_TASKS_TASK_OUTPUT_LIMIT':
                         six.text_type(self.profile_tasks_limit),
                 })
@@ -621,7 +633,8 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 os.chmod(command_path, 0o750)
 
             if self.command_timeout:
-                command = ['timeout', str(self.command_timeout)] + command
+                command = ['timeout', '-s', 'KILL',
+                           str(self.command_timeout)] + command
 
             if self.queue_name:
                 zaqar = self.get_messaging_client(context)
