@@ -294,6 +294,17 @@ class GeneratePasswordsAction(base.TripleOAction):
         except heat_exc.HTTPNotFound:
             stack_env = None
 
+        try:
+            # We can't rely on the existence of PlacementPassword to
+            # determine if placement extraction has occured as it was added
+            # in stein while the service extraction was delayed to train.
+            # Inspect the endpoint map instead.
+            endpoint_res = heat.resources.get(self.container, 'EndpointMap')
+            endpoints = endpoint_res.attributes.get('endpoint_map', {})
+            placement_extracted = 'PlacementPublic' in endpoints
+        except heat_exc.HTTPNotFound:
+            placement_extracted = False
+
         passwords = password_utils.generate_passwords(
             mistralclient=mistral,
             stack_env=stack_env,
@@ -311,6 +322,15 @@ class GeneratePasswordsAction(base.TripleOAction):
                 if i not in env['passwords']:
                     env['passwords'][i] = env['passwords']['RabbitPassword']
 
+        # NOTE(owalsh): placement previously used NovaPassword
+        # Default to the same password for PlacementPassword if it is an
+        # upgrade (i.e NovaPassword is set) so we do not need to update the
+        # password in keystone
+        if not placement_extracted and 'NovaPassword' in env['passwords']:
+            LOG.debug('Setting PlacementPassword to NovaPassword')
+            env['passwords']['PlacementPassword'] = \
+                env['passwords']['NovaPassword']
+
         # ensure all generated passwords are present in plan env,
         # but respect any values previously generated and stored
         for name, password in passwords.items():
@@ -682,6 +702,16 @@ class GetNetworkConfigAction(base.TripleOAction):
         if isinstance(processed_data, actions.Result):
             return processed_data
 
+        # Default temporary value is used when no user input for any
+        # interface routes for the role networks to find network config.
+        role_networks = processed_data['template'].get('resources', {}).get(
+            self.role_name + 'GroupVars', {}).get('properties', {}).get(
+                'value', {}).get('role_networks', [])
+        for nw in role_networks:
+            rt = nw + 'InterfaceRoutes'
+            if rt not in processed_data['environment']['parameter_defaults']:
+                processed_data['environment']['parameter_defaults'][rt] = [[]]
+
         # stacks.preview method raises validation message if stack is
         # already deployed. here renaming container to get preview data.
         container_temp = self.container + "-TEMP"
@@ -712,7 +742,9 @@ class GetNetworkConfigAction(base.TripleOAction):
                     ns_len = len(net_script)
                     start_index = (net_script.find(
                         "echo '{\"network_config\"", 0, ns_len) + 6)
-                    end_index = net_script.find("'", start_index, ns_len)
+                    # In file network/scripts/run-os-net-config.sh
+                    end_str = "' > /etc/os-net-config/config.json"
+                    end_index = net_script.find(end_str, start_index, ns_len)
                     if (end_index > start_index):
                         net_config = net_script[start_index:end_index]
                         if net_config:
