@@ -81,12 +81,9 @@ PASSWORD_PARAMETER_NAMES = (
     'BarbicanSimpleCryptoKek',
     'CeilometerMeteringSecret',
     'CeilometerPassword',
-    'CephAdminKey',
     'CephClientKey',
     'CephClusterFSID',
-    'CephMdsKey',
     'CephManilaClientKey',
-    'CephMonKey',
     'CephRgwKey',
     'CephGrafanaAdminPassword',
     'CephDashboardAdminPassword',
@@ -157,6 +154,10 @@ DO_NOT_ROTATE_LIST = (
     'KeystoneFernetKey0',
     'KeystoneFernetKey1',
     'KeystoneFernetKeys',
+    'CephClientKey',
+    'CephClusterFSID',
+    'CephManilaClientKey',
+    'CephRgwKey',
 )
 
 PLAN_NAME_PATTERN = '^[a-zA-Z0-9-]+$'
@@ -212,8 +213,6 @@ MISTRAL_WORK_DIR = '/var/lib/mistral'
 
 EXCLUSIVE_NEUTRON_DRIVERS = ['ovn', 'openvswitch']
 
-UPGRADE_STEPS_MAX = 6
+DEFAULT_STEPS_MAX = 6
 
-# Global Directories for clouds.yaml
-GLOBAL_OS_DIR = '/etc/openstack'
-CLOUDS_YAML_FILE = 'clouds.yaml'
+PER_STEP_TASKS = ['upgrade_tasks', 'deploy_steps_tasks']
