@@ -14,13 +14,16 @@
 #
 
 import collections
+import errno
 import hashlib
 import json
 import os
 import requests
+import six
 import shutil
 
 from oslo_log import log as logging
+from tripleo_common.utils import image as image_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -50,14 +53,25 @@ TYPE_KEYS = (
 TYPE_MAP_EXTENSION = '.type-map'
 
 
+def skip_if_exists(f):
+    @six.wraps(f)
+    def wrapper(*args, **kwargs):
+        try:
+            return f(*args, **kwargs)
+        except OSError as e:
+            # Handle race for the already existing entity
+            if e.errno == errno.EEXIST:
+                pass
+            else:
+                raise e
+    return wrapper
+
+
+@skip_if_exists
 def make_dir(path):
     if os.path.exists(path):
         return
-    try:
-        os.makedirs(path, 0o775)
-    except os.error:
-        # Handle race for directory already existing
-        pass
+    os.makedirs(path, 0o775)
 
 
 def image_tag_from_url(image_url):
@@ -76,6 +90,7 @@ def image_tag_from_url(image_url):
     return image, tag
 
 
+@skip_if_exists
 def export_stream(target_url, layer, layer_stream, verify_digest=True):
     image, _ = image_tag_from_url(target_url)
     digest = layer['digest']
@@ -88,6 +103,12 @@ def export_stream(target_url, layer, layer_stream, verify_digest=True):
     length = 0
     calc_digest = hashlib.sha256()
 
+    def remove_layer(image, blob_path):
+        if os.path.isfile(blob_path):
+            os.remove(blob_path)
+            LOG.error('[%s] Broken layer found and removed %s' %
+                      (image, blob_path))
+
     try:
         with open(blob_path, 'wb') as f:
             count = 0
@@ -102,13 +123,22 @@ def export_stream(target_url, layer, layer_stream, verify_digest=True):
                 length += len(chunk)
                 LOG.debug('[%s] Written %i bytes for %s' %
                           (image, length, digest))
+    except MemoryError as e:
+        memory_error = '[{}] Memory Error: {}'.format(image, str(e))
+        LOG.error(memory_error)
+        remove_layer(image, blob_path)
+        raise MemoryError(memory_error)
+    except requests.exceptions.HTTPError as e:
+        # catch http errors seperately as those can be retried in
+        # the image uploader
+        http_error = '[{}] HTTP error: {}'.format(image, str(e))
+        LOG.error(http_error)
+        remove_layer(image, blob_path)
+        raise
     except Exception as e:
         write_error = '[{}] Write Failure: {}'.format(image, str(e))
         LOG.error(write_error)
-        if os.path.isfile(blob_path):
-            os.remove(blob_path)
-            LOG.error('[%s] Broken layer found and removed %s' %
-                      (image, blob_path))
+        remove_layer(image, blob_path)
         raise IOError(write_error)
     else:
         LOG.info('[%s] Layer written successfully %s' % (image, blob_path))
@@ -143,39 +173,69 @@ def export_stream(target_url, layer, layer_stream, verify_digest=True):
         )
         if blob_path != expected_blob_path:
             os.rename(blob_path, expected_blob_path)
+            blob_path = expected_blob_path
 
     layer['digest'] = layer_digest
     layer['size'] = length
     LOG.debug('[%s] Done exporting image layer %s' % (image, digest))
-    return layer_digest
+    return (layer_digest, blob_path)
 
 
-def cross_repo_mount(target_image_url, image_layers, source_layers):
-    for layer in source_layers:
-        if layer not in image_layers:
-            continue
-
-        image_url = image_layers[layer]
-        image, tag = image_tag_from_url(image_url)
-        dir_path = os.path.join(IMAGE_EXPORT_DIR, 'v2', image, 'blobs')
-        blob_path = os.path.join(dir_path, '%s.gz' % layer)
-        if not os.path.exists(blob_path):
-            LOG.debug('[%s] Layer not found: %s' % (image, blob_path))
-            continue
-
-        target_image, tag = image_tag_from_url(target_image_url)
-        target_dir_path = os.path.join(
-            IMAGE_EXPORT_DIR, 'v2', target_image, 'blobs')
-        make_dir(target_dir_path)
-        target_blob_path = os.path.join(target_dir_path, '%s.gz' % layer)
-        if os.path.exists(target_blob_path):
-            continue
+@skip_if_exists
+def layer_cross_link(layer, image, blob_path, target_image_url):
+    target_image, _ = image_tag_from_url(target_image_url)
+    target_dir_path = os.path.join(
+        IMAGE_EXPORT_DIR, 'v2', target_image, 'blobs')
+    make_dir(target_dir_path)
+    target_blob_path = os.path.join(target_dir_path, '%s.gz' % layer)
+    if not os.path.exists(target_blob_path):
         LOG.debug('[%s] Linking layers: %s -> %s' %
                   (image, blob_path, target_blob_path))
         # make a hard link so the layers can have independent lifecycles
         os.link(blob_path, target_blob_path)
 
 
+def cross_repo_mount(target_image_url, image_layers, source_layers,
+                     uploaded_layers=None):
+    linked_layers = {}
+    target_image, _ = image_tag_from_url(target_image_url)
+    for layer in source_layers:
+        known_path, ref_image = image_utils.uploaded_layers_details(
+            uploaded_layers, layer, scope='local')
+
+        if layer not in image_layers and not ref_image:
+            continue
+
+        image_url = image_layers.get(layer, None)
+        if image_url:
+            image, _ = image_tag_from_url(image_url)
+        else:
+            image = ref_image
+        if not image:
+            continue
+
+        if known_path and ref_image:
+            blob_path = known_path
+            image = ref_image
+            if ref_image != image:
+                LOG.debug('[%s] Layer ref. by image %s already exists '
+                          'at %s' % (image, ref_image, known_path))
+            else:
+                LOG.debug('[%s] Layer already exists at %s'
+                          % (image, known_path))
+        else:
+            dir_path = os.path.join(IMAGE_EXPORT_DIR, 'v2', image, 'blobs')
+            blob_path = os.path.join(dir_path, '%s.gz' % layer)
+            if not os.path.exists(blob_path):
+                LOG.debug('[%s] Layer not found: %s' % (image, blob_path))
+                continue
+
+        layer_cross_link(layer, image, blob_path, target_image_url)
+        linked_layers.update({layer: {'known_path': blob_path,
+                                      'ref_image': image}})
+    return linked_layers
+
+
 def export_manifest_config(target_url,
                            manifest_str,
                            manifest_type,
@@ -267,8 +327,8 @@ def parse_type_map_file(type_map_path):
     content_type = None
     type_map = {}
     with open(type_map_path, 'r') as f:
-        for l in f:
-            line = l[:-1]
+        for x in f:
+            line = x[:-1]
             if not line:
                 if uri and content_type:
                     type_map[content_type] = uri
