@@ -16,6 +16,7 @@
 # under the License.
 
 from collections import OrderedDict
+import logging
 import os.path
 import sys
 import yaml
@@ -28,6 +29,10 @@ UNDERCLOUD_CONNECTION_SSH = 'ssh'
 
 UNDERCLOUD_CONNECTION_LOCAL = 'local'
 
+logging.basicConfig()
+LOG = logging.getLogger(__name__)
+LOG.setLevel(logging.INFO)
+
 
 class TemplateDumper(yaml.SafeDumper):
     def represent_ordered_dict(self, data):
@@ -47,26 +52,17 @@ class StackOutputs(object):
     on unnecessary Heat calls.
     """
 
-    def __init__(self, plan, hclient):
-        self.plan = plan
+    def __init__(self, stack):
         self.outputs = {}
-        self.hclient = hclient
-        self.stack = None
+        self.stack = stack
 
     def _load_outputs(self):
         """Load outputs from the stack if necessary
 
         Retrieves the stack outputs if that has not already happened.  If it
         has then this is a noop.
-
-        Sets the outputs to an empty dict if the stack is not found.
         """
-        if not self.stack:
-            try:
-                self.stack = self.hclient.stacks.get(self.plan)
-            except HTTPNotFound:
-                self.outputs = {}
-                return
+        if not self.outputs:
             self.outputs = {i['output_key']: i['output_value']
                             for i in self.stack.outputs
                             }
@@ -96,7 +92,6 @@ class TripleoInventory(object):
                  undercloud_key_file=None, serial=1):
         self.session = session
         self.hclient = hclient
-        self.hosts_format_dict = False
         self.host_network = host_network or HOST_NETWORK
         self.auth_url = auth_url
         self.cacert = cacert
@@ -106,7 +101,6 @@ class TripleoInventory(object):
         self.undercloud_key_file = undercloud_key_file
         self.plan_name = plan_name
         self.ansible_python_interpreter = ansible_python_interpreter
-        self.stack_outputs = StackOutputs(self.plan_name, self.hclient)
         self.hostvars = {}
         self.undercloud_connection = undercloud_connection
         self.serial = serial
@@ -146,17 +140,27 @@ class TripleoInventory(object):
         """
         return self.UNDERCLOUD_SERVICES
 
-    def _hosts(self, alist):
+    def _hosts(self, alist, dynamic=True):
         """Static yaml inventories reqire a different hosts format?!"""
-        if self.hosts_format_dict:
+        if not dynamic:
             return {x: {} for x in alist}
         else:
             return alist
 
-    def list(self):
+    def _get_stack(self):
+        try:
+            stack = self.hclient.stacks.get(self.plan_name)
+        except HTTPNotFound:
+            LOG.warning("Stack not found: %s. Only the undercloud will "
+                        "be added to the inventory." % self.plan_name)
+            stack = None
+
+        return stack
+
+    def list(self, dynamic=True):
         ret = OrderedDict({
             'Undercloud': {
-                'hosts': self._hosts(['undercloud']),
+                'hosts': self._hosts(['undercloud'], dynamic),
                 'vars': {
                     'ansible_host': 'localhost',
                     'ansible_python_interpreter': sys.executable,
@@ -191,19 +195,30 @@ class TripleoInventory(object):
                                                   interface='public')
         ret['Undercloud']['vars']['undercloud_swift_url'] = swift_url
 
-        keystone_url = self.stack_outputs.get('KeystoneURL')
-        if keystone_url:
-            ret['Undercloud']['vars']['overcloud_keystone_url'] = keystone_url
+        ret['Undercloud']['vars']['undercloud_service_list'] = \
+            self.get_undercloud_service_list()
+
         admin_password = self.get_overcloud_environment().get(
             'parameter_defaults', {}).get('AdminPassword')
         if admin_password:
             ret['Undercloud']['vars']['overcloud_admin_password'] =\
                 admin_password
+
+        if dynamic:
+            # Prevent Ansible from repeatedly calling us to get empty host
+            # details
+            ret['_meta'] = {'hostvars': self.hostvars}
+
+        self.stack = self._get_stack()
+        if not self.stack:
+            return ret
+        self.stack_outputs = StackOutputs(self.stack)
+
+        keystone_url = self.stack_outputs.get('KeystoneURL')
+        if keystone_url:
+            ret['Undercloud']['vars']['overcloud_keystone_url'] = keystone_url
+
         endpoint_map = self.stack_outputs.get('EndpointMap')
-
-        ret['Undercloud']['vars']['undercloud_service_list'] = \
-            self.get_undercloud_service_list()
-
         if endpoint_map:
             horizon_endpoint = endpoint_map.get('HorizonPublic', {}).get('uri')
             if horizon_endpoint:
@@ -234,10 +249,6 @@ class TripleoInventory(object):
                         hosts[name].update({
                             'deploy_server_id': role_node_id_map[
                                 'server_ids'][role][idx]})
-                    # Add variable for listing enabled networks in the node
-                    hosts[name].update({
-                        'enabled_networks':
-                            [str(net) for net in role_net_ip_map[role]]})
                     # Add variable for IP on each network
                     for net in role_net_ip_map[role]:
                         hosts[name].update({
@@ -249,16 +260,19 @@ class TripleoInventory(object):
                             "%s_hostname" % net:
                                 role_net_hostname_map[role][net][idx]})
 
-                    networks.update(hosts[name]['enabled_networks'])
-
                 children.append(role)
 
-                if self.hosts_format_dict:
+                if not dynamic:
                     hosts_format = hosts
                 else:
                     hosts_format = [h for h in hosts.keys()]
                     hosts_format.sort()
 
+                role_networks = sorted([
+                    str(net) for net in role_net_ip_map[role]
+                ])
+                networks.update(role_networks)
+
                 ret[role] = {
                     'hosts': hosts_format,
                     'vars': {
@@ -266,6 +280,7 @@ class TripleoInventory(object):
                         'bootstrap_server_id': role_node_id_map.get(
                             'bootstrap_server_id'),
                         'tripleo_role_name': role,
+                        'tripleo_role_networks': role_networks,
                         'serial': self.serial,
                     }
 
@@ -288,11 +303,20 @@ class TripleoInventory(object):
                 self.get_overcloud_environment().get(
                     'parameter_defaults', {}).get('ContainerCli')
 
-            ret['overcloud'] = {
-                'children': self._hosts(sorted(children)),
+            ret['allovercloud'] = {
+                'children': self._hosts(sorted(children), dynamic),
                 'vars': overcloud_vars
             }
 
+            ret[self.plan_name] = {
+                'children': self._hosts(['allovercloud'], dynamic)
+            }
+            if self.plan_name != 'overcloud':
+                ret['overcloud'] = {
+                    'children': self._hosts(['allovercloud'], dynamic),
+                    'deprecated': 'Deprecated by allovercloud group in Ussuri'
+                }
+
         # Associate services with roles
         roles_by_service = self.get_roles_by_service(
             self.stack_outputs.get('EnabledServices', {}))
@@ -324,7 +348,7 @@ class TripleoInventory(object):
             if service_children:
                 svc_host = service.lower()
                 ret[svc_host] = {
-                    'children': self._hosts(service_children),
+                    'children': self._hosts(service_children, dynamic),
                     'vars': {
                         'ansible_ssh_user': self.ansible_ssh_user
                     }
@@ -333,11 +357,6 @@ class TripleoInventory(object):
                     ret[svc_host]['vars']['ansible_python_interpreter'] = \
                         self.ansible_python_interpreter
 
-        if not self.hosts_format_dict:
-            # Prevent Ansible from repeatedly calling us to get empty host
-            # details
-            ret['_meta'] = {'hostvars': self.hostvars}
-
         return ret
 
     def host(self):
@@ -357,8 +376,7 @@ class TripleoInventory(object):
 
         # For some reason the json/yaml format needed for static and
         # dynamic inventories is different for the hosts/children?!
-        self.hosts_format_dict = True
-        inventory = self.list()
+        inventory = self.list(dynamic=False)
 
         if extra_vars:
             for var, value in extra_vars.items():
