@@ -78,7 +78,7 @@ class AnsiblePlaybookActionTest(base.TestCase):
         super(AnsiblePlaybookActionTest, self).setUp()
 
         self.playbook = "myplaybook"
-        self.limit_hosts = None
+        self.limit_hosts = "compute0,compute1"
         self.remote_user = 'fido'
         self.become = True
         self.become_user = 'root'
@@ -113,14 +113,15 @@ class AnsiblePlaybookActionTest(base.TestCase):
             'HOME': action.work_dir,
             'ANSIBLE_LOCAL_TEMP': action.work_dir,
             'ANSIBLE_CONFIG': ansible_config_path,
-            'ANSIBLE_CALLBACK_WHITELIST': 'profile_tasks',
+            'ANSIBLE_CALLBACK_WHITELIST': 'tripleo,profile_tasks',
+            'ANSIBLE_STDOUT_CALLBACK': 'tripleo',
             'PROFILE_TASKS_TASK_OUTPUT_LIMIT': '0',
         }
         python_version = sys.version_info.major
         ansible_playbook_cmd = 'ansible-playbook-{}'.format(python_version)
         mock_execute.assert_called_once_with(
-            ansible_playbook_cmd, '-v', pb, '--become',
-            '--become-user',
+            ansible_playbook_cmd, '-v', pb, '--limit', self.limit_hosts,
+            '--become', '--become-user',
             self.become_user, '--extra-vars', json.dumps(self.extra_vars),
             env_variables=env, cwd=action.work_dir,
             log_errors=processutils.LogErrors.ALL)
@@ -285,7 +286,8 @@ class CopyConfigFileTest(base.TestCase):
                              ansible_cfg.get('ssh_connection',
                                              'custom_option'))
 
-    def test_override_ansible_cfg_empty(self):
+    @mock.patch("multiprocessing.cpu_count")
+    def test_override_ansible_cfg_empty(self, cpu_count):
         with tempfile.NamedTemporaryFile() as ansible_cfg_file:
             ansible_cfg_path = ansible_cfg_file.name
             work_dir = tempfile.mkdtemp(prefix='ansible-mistral-action-test')
@@ -293,7 +295,7 @@ class CopyConfigFileTest(base.TestCase):
             ansible_cfg_file.write(b'[defaults]\n')
             ansible_cfg_file.write(b'[ssh_connection]\n')
             ansible_cfg_file.flush()
-
+            cpu_count.return_value = 4
             override_ansible_cfg = ""
 
             resulting_ansible_config = ansible.write_default_ansible_cfg(
@@ -303,4 +305,4 @@ class CopyConfigFileTest(base.TestCase):
             ansible_cfg = configparser.ConfigParser()
             ansible_cfg.read(resulting_ansible_config)
 
-            self.assertEqual('25', ansible_cfg.get('defaults', 'forks'))
+            self.assertEqual('40', ansible_cfg.get('defaults', 'forks'))
