@@ -48,10 +48,7 @@ _EXISTING_PASSWORDS = {
     'RabbitPassword': 'ahuHRXdPMx9rzCdjD9CJJNCgA',
     'RpcPassword': 'ahuHRXdPMx9rzCdjD9CJJNCgA',
     'NotifyPassword': 'ahuHRXdPMx9rzCdjD9CJJNCgA',
-    'CephAdminKey': b'AQCQXtlXAAAAABAAT4Gk+U8EqqStL+JFa9bp1Q==',
     'HAProxyStatsPassword': 'P8tbdK6n4YUkTaUyy8XgEVTe6',
-    'TackerPassword': 'DwcKvMqXMuNYYFU4zTCuG4234',
-    'TrovePassword': 'V7A7zegkMdRFnYuN23gdc4KQC',
     'CeilometerPassword': 'RRdpwK6qf2pbKz2UtzxqauAdk',
     'GnocchiPassword': 'cRYHcUkMuJeK3vyU9pCaznUZc',
     'HeatStackDomainAdminPassword': 'GgTRyWzKYsxK4mReTJ4CM6sMc',
@@ -64,9 +61,7 @@ _EXISTING_PASSWORDS = {
     'OctaviaCaKeyPassphrase': 'SLj4c3uCk4DDxPwQOG1Heb==',
     'ManilaPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
     'NeutronMetadataProxySharedSecret': 'Q2YgUCwmBkYdqsdhhCF4hbghu',
-    'CephMdsKey': b'AQCQXtlXAAAAABAAT4Gk+U8EqqStL+JFa9bp1Q==',
     'CephManilaClientKey': b'AQANOFFY1NW6AxAAu6jWI3YSOsp2QWusb5Y3DQ==',
-    'CephMonKey': b'AQCQXtlXAAAAABAA9l+59N3yH+C49Y0JiKeGFg==',
     'CephGrafanaAdminPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
     'CephDashboardAdminPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
     'SwiftHashSuffix': 'td8mV6k7TYEGKCDvjVBwckpn9',
@@ -628,6 +623,9 @@ class GeneratePasswordsActionTest(base.TestCase):
         }
         mock_resource = mock.MagicMock()
         mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
             'value': 'existing_value'
         }
         mock_orchestration.resources.get.return_value = mock_resource
@@ -697,6 +695,14 @@ class GeneratePasswordsActionTest(base.TestCase):
         mock_orchestration.stacks.environment.return_value = {
             'parameter_defaults': {}
         }
+        mock_resource = mock.MagicMock()
+        mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
+            'value': None
+        }
+        mock_orchestration.resources.get.return_value = mock_resource
         mock_get_orchestration_client.return_value = mock_orchestration
 
         action = parameters.GeneratePasswordsAction()
@@ -710,6 +716,68 @@ class GeneratePasswordsActionTest(base.TestCase):
             "tripleo.parameters.get"
         )
 
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'cache_delete')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'get_orchestration_client')
+    @mock.patch('tripleo_common.utils.passwords.'
+                'create_ssh_keypair')
+    @mock.patch('tripleo_common.utils.passwords.'
+                'create_fernet_keys_repo_structure_and_keys')
+    @mock.patch('tripleo_common.utils.passwords.'
+                'get_snmpd_readonly_user_password')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'get_workflow_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
+    def test_placement_passwords_upgrade(self, mock_get_object_client,
+                                         mock_get_workflow_client,
+                                         mock_get_snmpd_readonly_user_password,
+                                         mock_fernet_keys_setup,
+                                         mock_create_ssh_keypair,
+                                         mock_get_orchestration_client,
+                                         mock_cache):
+
+        mock_get_snmpd_readonly_user_password.return_value = "TestPassword"
+        mock_create_ssh_keypair.return_value = {'public_key': 'Foo',
+                                                'private_key': 'Bar'}
+        mock_fernet_keys_setup.return_value = {'/tmp/foo': {'content': 'Foo'},
+                                               '/tmp/bar': {'content': 'Bar'}}
+
+        passwords = _EXISTING_PASSWORDS.copy()
+
+        mock_ctx = mock.MagicMock()
+
+        swift = mock.MagicMock(url="http://test.com")
+        mock_env = yaml.safe_dump({
+            'name': constants.DEFAULT_CONTAINER_NAME,
+            'temp_environment': 'temp_environment',
+            'template': 'template',
+            'environments': [{u'path': u'environments/test.yaml'}],
+            'passwords': passwords
+        }, default_flow_style=False)
+        swift.get_object.return_value = ({}, mock_env)
+        mock_get_object_client.return_value = swift
+
+        mock_orchestration = mock.MagicMock()
+        mock_orchestration.stacks.environment.return_value = {
+            'parameter_defaults': {}
+        }
+        mock_resource = mock.MagicMock()
+        mock_resource.attributes = {
+            'endpoint_map': {},
+            'value': None
+        }
+        mock_orchestration.resources.get.return_value = mock_resource
+        mock_get_orchestration_client.return_value = mock_orchestration
+
+        action = parameters.GeneratePasswordsAction()
+        result = action.run(mock_ctx)
+
+        self.assertEqual(
+            passwords['NovaPassword'],
+            result['PlacementPassword']
+        )
+
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'cache_delete')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
@@ -754,9 +822,11 @@ class GeneratePasswordsActionTest(base.TestCase):
         mock_orchestration.stacks.environment.return_value = {
             'parameter_defaults': {}
         }
-
         mock_resource = mock.MagicMock()
         mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
             'value': 'existing_value'
         }
         mock_orchestration.resources.get.return_value = mock_resource
@@ -827,6 +897,9 @@ class GeneratePasswordsActionTest(base.TestCase):
         }
         mock_resource = mock.MagicMock()
         mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
             'value': 'existing_value'
         }
         mock_orchestration.resources.get.return_value = mock_resource
@@ -911,6 +984,14 @@ class GeneratePasswordsActionTest(base.TestCase):
                 'AdminPassword': 'ExistingPasswordInHeat',
             }
         }
+        mock_resource = mock.MagicMock()
+        mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
+            'value': None
+        }
+        mock_orchestration.resources.get.return_value = mock_resource
         mock_get_orchestration_client.return_value = mock_orchestration
 
         action = parameters.GeneratePasswordsAction()
@@ -946,6 +1027,14 @@ class GetPasswordsActionTest(base.TestCase):
         mock_get_object_client.return_value = swift
 
         mock_orchestration = mock.MagicMock()
+        mock_resource = mock.MagicMock()
+        mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
+            'value': None
+        }
+        mock_orchestration.resources.get.return_value = mock_resource
         mock_get_orchestration_client.return_value = mock_orchestration
 
         action = parameters.GetPasswordsAction()
@@ -974,6 +1063,15 @@ class GetPasswordsActionTest(base.TestCase):
         mock_get_object_client.return_value = swift
 
         mock_orchestration = mock.MagicMock()
+        mock_resource = mock.MagicMock()
+        mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
+            'value': None
+        }
+        mock_orchestration.resources.get.return_value = mock_resource
+
         mock_get_orchestration_client.return_value = mock_orchestration
 
         action = parameters.GetPasswordsAction()
@@ -1005,6 +1103,14 @@ class GetPasswordsActionTest(base.TestCase):
         mock_get_object_client.return_value = swift
 
         mock_orchestration = mock.MagicMock()
+        mock_resource = mock.MagicMock()
+        mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
+            'value': None
+        }
+        mock_orchestration.resources.get.return_value = mock_resource
         mock_get_orchestration_client.return_value = mock_orchestration
 
         action = parameters.GetPasswordsAction()
@@ -1484,7 +1590,8 @@ class GetNetworkConfigActionTest(base.TestCase):
         mock_heat.stacks.preview.return_value = mock.Mock(resources=[{
             "resource_identity": {"stack_name": "overcloud-TEMP-Compute-0"},
             "resource_name": "OsNetConfigImpl",
-            "properties": {"config": "echo \'{\"network_config\": {}}\'"}
+            "properties": {"config": "echo \'{\"network_config\": {}}\'"
+                           " > /etc/os-net-config/config.json"}
             }])
 
         mock_get_orchestration_client.return_value = mock_heat
@@ -1503,6 +1610,151 @@ class GetNetworkConfigActionTest(base.TestCase):
             stack_name='overcloud-TEMP',
         )
 
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'cache_set')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'cache_get')
+    @mock.patch('heatclient.common.template_utils.'
+                'process_multiple_environments_and_files')
+    @mock.patch('heatclient.common.template_utils.get_template_contents')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'get_orchestration_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'get_workflow_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
+    def test_run_valid_network_config_with_no_interface_routes_inputs(
+            self, mock_get_object_client, mock_get_workflow_client,
+            mock_get_orchestration_client, mock_get_template_contents,
+            mock_process_multiple_environments_and_files,
+            mock_cache_get,
+            mock_cache_set):
+
+        mock_ctx = mock.MagicMock()
+        swift = mock.MagicMock(url="http://test.com")
+        mock_env = yaml.safe_dump({
+            'temp_environment': 'temp_environment',
+            'template': 'template',
+            'environments': [{u'path': u'environments/test.yaml'}]
+        }, default_flow_style=False)
+        swift.get_object.side_effect = (
+            ({}, mock_env),
+            swiftexceptions.ClientException('atest2'),
+            ({}, mock_env)
+        )
+        mock_get_object_client.return_value = swift
+
+        mock_get_template_contents.return_value = ({}, {
+            'heat_template_version': '2016-04-30',
+            'resources': {'ComputeGroupVars': {'properties': {
+                'value': {'role_networks': ['InternalApi', 'Storage']}
+                }
+            }}
+        })
+        mock_process_multiple_environments_and_files.return_value = (
+            {}, {'parameter_defaults': {}})
+
+        mock_heat = mock.MagicMock()
+        mock_heat.stacks.preview.return_value = mock.Mock(resources=[{
+            "resource_identity": {"stack_name": "overcloud-TEMP-Compute-0"},
+            "resource_name": "OsNetConfigImpl",
+            "properties": {"config": "echo \'{\"network_config\": {}}\'"
+                           " > /etc/os-net-config/config.json"}
+            }])
+
+        mock_get_orchestration_client.return_value = mock_heat
+
+        mock_cache_get.return_value = None
+        expected = {"network_config": {}}
+        # Test
+        action = parameters.GetNetworkConfigAction(container='overcloud',
+                                                   role_name='Compute')
+        result = action.run(mock_ctx)
+        self.assertEqual(expected, result)
+        mock_heat.stacks.preview.assert_called_once_with(
+            environment={'parameter_defaults': {
+                'InternalApiInterfaceRoutes': [[]],
+                'StorageInterfaceRoutes': [[]]}},
+            files={},
+            template={'heat_template_version': '2016-04-30',
+                      'resources': {'ComputeGroupVars': {
+                          'properties': {'value': {
+                              'role_networks': ['InternalApi',
+                                                'Storage']}}}}},
+            stack_name='overcloud-TEMP',
+        )
+
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'cache_set')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'cache_get')
+    @mock.patch('heatclient.common.template_utils.'
+                'process_multiple_environments_and_files')
+    @mock.patch('heatclient.common.template_utils.get_template_contents')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'get_orchestration_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'get_workflow_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
+    def test_run_valid_network_config_with_interface_routes_inputs(
+            self, mock_get_object_client, mock_get_workflow_client,
+            mock_get_orchestration_client, mock_get_template_contents,
+            mock_process_multiple_environments_and_files,
+            mock_cache_get,
+            mock_cache_set):
+
+        mock_ctx = mock.MagicMock()
+        swift = mock.MagicMock(url="http://test.com")
+        mock_env = yaml.safe_dump({
+            'temp_environment': 'temp_environment',
+            'template': 'template',
+            'environments': [{u'path': u'environments/test.yaml'}]
+        }, default_flow_style=False)
+        swift.get_object.side_effect = (
+            ({}, mock_env),
+            swiftexceptions.ClientException('atest2'),
+            ({}, mock_env)
+        )
+        mock_get_object_client.return_value = swift
+
+        mock_get_template_contents.return_value = ({}, {
+            'heat_template_version': '2016-04-30',
+            'resources': {'ComputeGroupVars': {'properties': {
+                'value': {'role_networks': ['InternalApi', 'Storage']}}}}
+        })
+        mock_process_multiple_environments_and_files.return_value = (
+            {}, {'parameter_defaults': {
+                'InternalApiInterfaceRoutes': ['test1'],
+                'StorageInterfaceRoutes': ['test2']}})
+
+        mock_heat = mock.MagicMock()
+        mock_heat.stacks.preview.return_value = mock.Mock(resources=[{
+            "resource_identity": {"stack_name": "overcloud-TEMP-Compute-0"},
+            "resource_name": "OsNetConfigImpl",
+            "properties": {"config": "echo \'{\"network_config\": {}}\'"
+                           " > /etc/os-net-config/config.json"}
+            }])
+
+        mock_get_orchestration_client.return_value = mock_heat
+
+        mock_cache_get.return_value = None
+        expected = {"network_config": {}}
+        # Test
+        action = parameters.GetNetworkConfigAction(container='overcloud',
+                                                   role_name='Compute')
+        result = action.run(mock_ctx)
+        self.assertEqual(expected, result)
+        mock_heat.stacks.preview.assert_called_once_with(
+            environment={'parameter_defaults': {
+                'InternalApiInterfaceRoutes': ['test1'],
+                'StorageInterfaceRoutes': ['test2']}},
+            files={},
+            template={'heat_template_version': '2016-04-30',
+                      'resources': {'ComputeGroupVars': {'properties': {
+                          'value': {'role_networks': ['InternalApi',
+                                                      'Storage']}}}}},
+            stack_name='overcloud-TEMP',
+        )
+
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'cache_set')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
