@@ -16,6 +16,7 @@
 import hashlib
 import io
 import json
+import mock
 import os
 import requests
 import shutil
@@ -105,6 +106,23 @@ class TestImageExport(base.TestCase):
         with open(blob_path, 'rb') as f:
             self.assertEqual(blob_compressed, f.read())
 
+    @mock.patch('tripleo_common.image.image_export.open',
+                side_effect=MemoryError())
+    def test_export_stream_memory_error(self, mock_open):
+        blob_data = six.b('The Blob')
+        blob_compressed = zlib.compress(blob_data)
+        calc_digest = hashlib.sha256()
+        calc_digest.update(blob_compressed)
+
+        target_url = urlparse('docker://localhost:8787/t/nova-api:latest')
+        layer = {
+            'digest': 'sha256:somethingelse'
+        }
+        calc_digest = hashlib.sha256()
+        layer_stream = io.BytesIO(blob_compressed)
+        self.assertRaises(MemoryError, image_export.export_stream,
+                          target_url, layer, layer_stream, verify_digest=False)
+
     def test_export_stream_verify_failed(self):
         blob_data = six.b('The Blob')
         blob_compressed = zlib.compress(blob_data)
@@ -331,12 +349,12 @@ URI: sha256:1234abcd/index.json
         if manifest.get('schemaVersion', 2) == 1:
             config_str = None
             manifest_type = image_uploader.MEDIA_MANIFEST_V1
-            layers = list(reversed([l['blobSum']
-                                    for l in manifest['fsLayers']]))
+            layers = list(reversed([x['blobSum']
+                                    for x in manifest['fsLayers']]))
         else:
             config_str = '{"config": {}}'
             manifest_type = image_uploader.MEDIA_MANIFEST_V2
-            layers = [l['digest'] for l in manifest['layers']]
+            layers = [x['digest'] for x in manifest['layers']]
         manifest_str = json.dumps(manifest)
         calc_digest = hashlib.sha256()
         calc_digest.update(manifest_str.encode('utf-8'))
