@@ -116,10 +116,10 @@ class TestKollaImageBuilder(base.TestCase):
             'kolla-build',
             '--config-file',
             'kolla-config.conf',
-            'nova-compute',
-            'nova-libvirt',
-            'heat-docker-agents-centos',
-            'image-with-missing-tag',
+            '^nova-compute$',
+            '^nova-libvirt$',
+            '^heat-docker-agents-centos$',
+            '^image-with-missing-tag$',
         ], env=env, stdout=-1, universal_newlines=True)
 
     @mock.patch('tripleo_common.image.base.open',
@@ -141,10 +141,10 @@ class TestKollaImageBuilder(base.TestCase):
             'kolla-build',
             '--config-file',
             'kolla-config.conf',
-            'nova-compute',
-            'nova-libvirt',
-            'heat-docker-agents-centos',
-            'image-with-missing-tag',
+            '^nova-compute$',
+            '^nova-libvirt$',
+            '^heat-docker-agents-centos$',
+            '^image-with-missing-tag$',
             '--template-only',
             '--work-dir', '/tmp/kolla',
         ], env=env, stdout=-1, universal_newlines=True)
@@ -152,10 +152,10 @@ class TestKollaImageBuilder(base.TestCase):
             'kolla-build',
             '--config-file',
             'kolla-config.conf',
-            'nova-compute',
-            'nova-libvirt',
-            'heat-docker-agents-centos',
-            'image-with-missing-tag',
+            '^nova-compute$',
+            '^nova-libvirt$',
+            '^heat-docker-agents-centos$',
+            '^image-with-missing-tag$',
             '--list-dependencies',
         ], env=env, stdout=-1, stderr=-1, universal_newlines=True)
         calls = [call1, call2]
@@ -197,9 +197,9 @@ class TestKollaImageBuilder(base.TestCase):
             'kolla-build',
             '--config-file',
             'kolla-config.conf',
-            'nova-libvirt',
-            'heat-docker-agents-centos',
-            'image-with-missing-tag',
+            '^nova-libvirt$',
+            '^heat-docker-agents-centos$',
+            '^image-with-missing-tag$',
         ], env=env, stdout=-1, universal_newlines=True)
 
 
@@ -236,7 +236,7 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'namespace': 'docker.io/tripleotrain',
                 'ceph_namespace': 'docker.io/ceph',
                 'ceph_image': 'daemon',
-                'ceph_tag': 'v4.0.4-stable-4.0-nautilus-centos-7-x86_64',
+                'ceph_tag': 'v4.0.12-stable-4.0-nautilus-centos-7-x86_64',
                 'ceph_grafana_namespace': 'docker.io/grafana',
                 'ceph_grafana_image': 'grafana',
                 'ceph_grafana_tag': '5.2.4',
