@@ -51,17 +51,18 @@ class TestConfig(base.TestCase):
                             'service_names',
                             'upgrade_batch_tasks', 'upgrade_tasks',
                             'external_deploy_tasks']
-        fake_role = [role for role in
-                     fakes.FAKE_STACK['outputs'][1]['output_value']]
 
         heat = mock.MagicMock()
         heat.stacks.get.return_value = fakes.create_tht_stack()
         self.config = ooo_config.Config(heat)
+        self.config.fetch_config('overcloud')
+        fake_role = list(self.config.stack_outputs.get('RoleData'))
         self.config.download_config('overcloud', '/tmp/tht', config_type_list)
 
         mock_git_init.assert_called_once_with('/tmp/tht')
         expected_mkdir_calls = [call('/tmp/tht/%s' % r) for r in fake_role]
         mock_mkdir.assert_has_calls(expected_mkdir_calls, any_order=True)
+        mock_mkdir.assert_called()
         expected_calls = []
         for config in config_type_list:
             for role in fake_role:
@@ -91,12 +92,12 @@ class TestConfig(base.TestCase):
                                               mock_git_init):
 
         expected_config_type = 'config_settings'
-        fake_role = [role for role in
-                     fakes.FAKE_STACK['outputs'][1]['output_value']]
 
         heat = mock.MagicMock()
         heat.stacks.get.return_value = fakes.create_tht_stack()
         self.config = ooo_config.Config(heat)
+        self.config.fetch_config('overcloud')
+        fake_role = list(self.config.stack_outputs.get('RoleData'))
         self.config.download_config('overcloud', '/tmp/tht',
                                     ['config_settings'])
         expected_mkdir_calls = [call('/tmp/tht/%s' % r) for r in fake_role]
@@ -104,6 +105,7 @@ class TestConfig(base.TestCase):
                           % (r, expected_config_type))
                           for r in fake_role]
         mock_mkdir.assert_has_calls(expected_mkdir_calls, any_order=True)
+        mock_mkdir.assert_called()
         mock_open.assert_has_calls(expected_calls, any_order=True)
         mock_git_init.assert_called_once_with('/tmp/tht')
 
@@ -128,9 +130,9 @@ class TestConfig(base.TestCase):
         heat = mock.MagicMock()
         heat.stacks.get.return_value = fakes.create_tht_stack()
         self.config = ooo_config.Config(heat)
+        self.config.fetch_config('overcloud')
         self.tmp_dir = self.useFixture(fixtures.TempDir()).path
-        fake_role = [role for role in
-                     fakes.FAKE_STACK['outputs'][1]['output_value']]
+        fake_role = list(self.config.stack_outputs.get('RoleData'))
         expected_tasks = {'FakeController': {0: [],
                                              1: [{'name': 'Stop fake service',
                                                   'service': 'name=fake '
@@ -145,7 +147,7 @@ class TestConfig(base.TestCase):
                                                'service': 'name=fake '
                                                'state=stopped',
                                                'when': ['nova_api_enabled.rc'
-                                                        ' == 0',
+                                                        ' == 0', False,
                                                         'httpd_enabled.rc'
                                                         ' != 0',
                                                         'step|int == 1']}],
@@ -164,11 +166,11 @@ class TestConfig(base.TestCase):
         for role in fake_role:
             filedir = os.path.join(self.tmp_dir, role)
             os.makedirs(filedir)
-            for step in range(constants.UPGRADE_STEPS_MAX):
+            for step in range(constants.DEFAULT_STEPS_MAX):
                 filepath = os.path.join(filedir, "upgrade_tasks_step%s.yaml"
                                         % step)
                 playbook_tasks = self.config._write_tasks_per_step(
-                    fakes.FAKE_STACK['outputs'][1]['output_value'][role]
+                    self.config.stack_outputs.get('RoleData')[role]
                     ['upgrade_tasks'], role, filepath, step)
                 self.assertTrue(os.path.isfile(filepath))
                 self.assertEqual(expected_tasks[role][step], playbook_tasks)
@@ -315,10 +317,19 @@ class TestConfig(base.TestCase):
                          'uuid': 2},
                      'overcloud-novacompute-2': {
                          'uuid': 3}}}},
+            {'output_key': 'RoleData',
+             'output_value': {
+                 'Controller': {
+                     'ansible_group_vars': {
+                         'chrony_host': 'localhost',
+                         'chrony_acl': 'none',
+                     }}}},
             {'output_key': 'RoleGroupVars',
              'output_value': {
                  'Controller': {
                      'any_errors_fatal': True,
+                     'chrony_host': '192.168.2.1',
+                     'chrony_foo': 'bar',
                      'max_fail_percentage': 15},
                  'Compute': {
                      'any_errors_fatal': True,
@@ -640,13 +651,13 @@ class TestConfig(base.TestCase):
                             'service_names',
                             'upgrade_batch_tasks', 'upgrade_tasks',
                             'external_deploy_tasks']
-        fake_role = [role for role in
-                     fakes.FAKE_STACK['outputs'][1]['output_value']]
 
         mock_os_path_exists.get.return_value = True
         heat = mock.MagicMock()
         heat.stacks.get.return_value = fakes.create_tht_stack()
         self.config = ooo_config.Config(heat)
+        self.config.fetch_config('overcloud')
+        fake_role = list(self.config.stack_outputs.get('RoleData'))
         self.config.download_config('overcloud', '/tmp/tht', config_type_list,
                                     False)
 
@@ -656,6 +667,7 @@ class TestConfig(base.TestCase):
 
         expected_mkdir_calls = [call('/tmp/tht/%s' % r) for r in fake_role]
         mock_mkdir.assert_has_calls(expected_mkdir_calls, any_order=True)
+        mock_mkdir.assert_called()
         expected_calls = []
         for config in config_type_list:
             for role in fake_role:
@@ -719,10 +731,19 @@ class TestConfig(base.TestCase):
                          'a7db3010-a51f-4ae0-a791-2364d629d20d',
                          '8b07cd31-3083-4b88-a433-955f72039e2c',
                          '169b46f8-1965-4d90-a7de-f36fb4a830fe']}}},
+            {'output_key': 'RoleData',
+             'output_value': {
+                 'Controller': {
+                     'ansible_group_vars': {
+                         'chrony_host': 'localhost',
+                         'chrony_acl': 'none',
+                     }}}},
             {'output_key': 'RoleGroupVars',
              'output_value': {
                  'Controller': {
                      'any_errors_fatal': True,
+                     'chrony_host': '192.168.2.1',
+                     'chrony_foo': 'bar',
                      'max_fail_percentage': 15},
                  'Compute': {
                      'any_errors_fatal': True,
@@ -871,12 +892,13 @@ class TestConfig(base.TestCase):
 
         self.config = ooo_config.Config(heat)
         stack = mock.Mock()
-        server_roles = dict(Controller='controller')
-        mock_get_network_config_data.return_value = dict(Controller='config')
+        server_roles = dict(node1='Controller')
+        mock_get_network_config_data.return_value = dict(node1='config',
+                                                         node2='config')
         config_dir = '/tmp/tht'
         self.config.render_network_config(stack, config_dir, server_roles)
         self.assertEqual(2, mock_open.call_count)
-        self.assertEqual('/tmp/tht/controller/Controller/NetworkConfig',
+        self.assertEqual('/tmp/tht/Controller/node1/NetworkConfig',
                          mock_open.call_args_list[0][0][0])
-        self.assertEqual('/tmp/tht/controller/NetworkConfig',
+        self.assertEqual('/tmp/tht/Controller/NetworkConfig',
                          mock_open.call_args_list[1][0][0])
