@@ -50,7 +50,8 @@ class Config(object):
                 for idx, name in enumerate(shortnames):
                     if 'server_ids' in role_node_id_map:
                         server_id = role_node_id_map['server_ids'][role][idx]
-                        servers[server_id] = name.lower()
+                        if server_id is not None:
+                            servers[server_id] = name.lower()
         return servers
 
     def get_network_config_data(self, stack):
@@ -125,8 +126,14 @@ class Config(object):
             if not isinstance(whenexpr, list):
                 whenexpr = [whenexpr]
             for w in whenexpr:
+                # "when" accepts booleans and regex only work for strings
+                if not isinstance(w, six.string_types):
+                    continue
+                # remove all spaces to make the regex match easier
+                w = re.sub(r'\s+', '', w)
                 # make \|int optional incase forgotten; use only step digit:
-                match = re.search(r'step(\|int)? == ([0-9]+)$', "%s" % w)
+                # ()'s around step|int are also optional
+                match = re.search(r'\(?step(\|int)?\)?==([0-9]+)$', "%s" % w)
                 if match:
                     if match.group(2) == str(step):
                         return True
@@ -242,23 +249,22 @@ class Config(object):
                     with self._open_file(filepath) as param_config:
                         param_config.write(json.dumps(role[config]))
                 elif config == 'ansible_group_vars':
-                    # NOTE(aschultz): ansible group vars are for specific role
-                    # services so we merge them in with the others so they
-                    # end up in the role vars. This means the last var
-                    # definition wins and will override them all.
-                    if role_name not in role_group_vars:
-                        role_group_vars[role_name] = {}
-                    role_group_vars[role_name].update(role[config])
+                    role_config = role[config].copy()
+                    role_config.update(role_group_vars[role_name])
+                    role_group_vars[role_name] = role_config
                 else:
-                    # NOTE(jfrancoa): Move this upgrade_tasks condition to the
-                    # upper level once THT is adapted. We include it here to
-                    # allow the CI to pass until THT changed is not merged.
-                    if config == 'upgrade_tasks':
-                        for i in range(constants.UPGRADE_STEPS_MAX):
+                    # NOTE(emilien): Move this condition to the
+                    # upper level once THT is adapted for all tasks to be
+                    # run per step.
+                    # We include it here to allow the CI to pass until THT
+                    # changed is not merged.
+                    if config in constants.PER_STEP_TASKS:
+                        for i in range(constants.DEFAULT_STEPS_MAX):
                             filepath = os.path.join(role_path, '%s_step%s.yaml'
                                                     % (config, i))
                             self._write_tasks_per_step(role[config], role_name,
                                                        filepath, i)
+
                     try:
                         data = role[config]
                     except KeyError as e:
